#ifndef _TASK_INFO_MANAGER_RELEASE_H__
#define _TASK_INFO_MANAGER_RELEASE_H__

#include <stdint.h>

#define MAX_HEADER_LEN  (256*1024)
#define INFO_HASH_SIZE  (20)
#define CID_SIZE                (20)
#define MAX_VERSION_LEN         (64)
#define MAX_CONTENT_TYPE_LEN    (64)
#define MAX_SYSTEM_VERSION_LEN  (256)
#define MAX_FILENAME_LEN        (256)
#define MAX_FILEPATH_LEN        (512)
#define MAX_URL_LEN             (2*1024)

typedef enum XL_ERRNO_CODE
{
    XL_NO_ERRNO                 = 9000,

    XL_ALREADY_INIT             = 9101,
    XL_SDK_NOT_INIT             = 9102,


    XL_TASK_ALREADY_EXIST       = 9103,
    XL_TASK_NOT_EXIST           = 9104,
    XL_TASK_ALREADY_STOPPED     = 9105,
    XL_TASK_ALREADY_RUNNING     = 9106,
    XL_TASK_NOT_START           = 9107,
    XL_TASK_STILL_RUNNING       = 9108,


    XL_FILE_EXISTED             = 9109,
    XL_DISK_FULL                = 9110,
    XL_TOO_MUCH_TASK            = 9111,
    XL_PARAM_ERROR              = 9112,
    XL_SCHEMA_NOT_SUPPORT       = 9113,
    XL_DYNAMIC_PARAM_FAIL       = 9114,
    XL_CONTINUE_NO_NAME         = 9115,
    XL_APPNAME_APPKEY_ERROR     = 9116,
    XL_CREATE_THREAD_ERROR      = 9117,
    XL_TASK_FINISH              = 9118,
    XL_TASK_NOT_RUNNING         = 9119,
    XL_TASK_NOT_IDLE            = 9120,
    XL_TASK_TYPE_NOT_SUPPORT    = 9121,
    XL_ADD_RESOURCE_ERROR       = 9122,
    XL_FUNCTION_NOT_SUPPORT     = 9123,
    XL_ALREADY_HAS_FILENAME     = 9124,

    XL_FILE_NAME_TOO_LONG       = 9125, /// 文件名太长
    XL_ONE_PATH_LEVEL_NAME_TOO_LONG = 9126, /// 存在一级的目录的名称太长
    XL_FULL_PATH_NAME_TOO_LONG  = 9127, /// 全路径名称太长
    XL_FULL_PATH_NAME_OCCUPIED  = 9128, /// 文件名被占用
    XL_TASK_NO_FILE_NAME        = 9129, /// 任务文件名不存在
    //BT EMule
    XL_NO_ENOUGH_BUFFER         = 9301,
    XL_TORRENT_PARSE_ERROR      = 9302,
    XL_INDEX_NOT_READY          = 9303,
    XL_TORRENT_IMCOMPLETE       = 9304,
    XL_THUNDER_URL_PARSE_ERROR  = 9305,
    //边下边播
    XL_HTTP_SERVER_NOT_START    = 9400,
    XL_TASK_FILE_NAME_EMPTY     = 9401,
    XL_TASK_FILE_NOT_VEDIO      = 9402,
    XL_TASK_UNKNOWN_ERROR       = 9403, /// 程序内部没有拦截并进行出的错误

} XL_ERRNO_CODE;


typedef enum _XL_TASK_STATUS
{
    XL_TASK_S_IDLE = 0,         // 初始状态
    XL_TASK_S_RUNNING,          // 正在下载
    XL_TASK_S_SUCCESS,          // 任务成功
    XL_TASK_S_FAILED,           // 任务失败
    XL_TASK_S_STOPPED           // 任务已停止
} XL_TASK_STATUS;

typedef enum _XL_CREATE_TASK_MODE
{
    XL_NEW_TASK = 0,            // 新建任务
    XL_CONTINUE_TASK = 1        // 续传任务
} XL_CREATE_TASK_MODE;
typedef enum _QUERY_INDEX_STATUS
{
    QIS_UNQUERY = 0,            //初始状态不查询索引
    QIS_QUERYING,               //正在查询索引
    QIS_QUERY_HAVE_INFO,        //查询到索引信息
    QIS_QUERY_HAVENT_INFO,      //未查询到有效索引信息
} QUERY_INDEX_STATUS;

typedef enum _RES_USE_STRATEGY
{
    RUS_NOMAL_USE = -1,     // 正常使用, 内部自己添加的资源
    RUS_PRIOR_USE = 0,      // 优先使用
} RES_USE_STRATEGY;
// 该类型使用位的方式扩展
typedef enum _DOWNLOADLIB_RESOURCE_TYPE
{
    RT_ALL = -1,               // 允许使用所有下载库支持的资源
    RT_ORIGIN = 1,             // 允许使用原始资源
    RT_MIRROR = 2,                  // 镜像资源
    RT_SIMILAR = 4,                 // 相似资源
    RT_P2P = 8,                     // 普通p2p资源
    RT_DCDN = 16,                   // DCDN资源
} DOWNLOADLIB_RESOURCE_TYPE;

typedef enum _DOWNLOADLIB_RESOURCE_DEMAND
{
    DRD_ERROR = 0,
    DRD_ORIGIN,                 // 多连接原始资源
    DRD_SINGLE_ORIGIN,              //单链接原始资源
    DRD_P2SP,                        //默认p2sp资源
} DOWNLOADLIB_RESOURCE_DEMAND;

typedef enum _NetWorkType
{
    NWT_None = 0,              //断网
    NWT_Phone = 1,             // 手机网络
    NWT_Mobile2G = 2,         //2G
    NWT_Mobile3G = 3,         //3G
    NWT_Mobile4G = 4,         //4G
    NWT_Unknown = 5,          //未知
    NWT_Wifi = 9,             //wifi
} NetWorkType;

typedef enum _NetWorkCarrier
{
    NWC_Unknow,   // 未知
    NWC_CMCC,     // 移动
    NWC_CU,       // 联通
    NWC_CT,       // 电信
} NetWorkCarrier;




typedef enum _GET_DOWNLOAD_HEADER_STATE
{
    GDHS_UNKOWN,
    GDHS_REQUESTING,  //? useless?
    GDHS_SUCCESS,
    GDHS_ERROR
} GET_DOWNLOAD_HEADER_STATE;

typedef enum _ORIGIN_RES_STATE
{
    ORIGIN_RES_UNUSED,            /// 还未使用
    ORIGIN_RES_CHECKING,          /// 检查中
    ORIGIN_RES_VALID_LINK,        /// 有效链接
    ORIGIN_RES_DEATH_LINK         /// 死链
} ORIGIN_RES_STATE;




typedef struct TAG_XL_RES_TRANSFER_INFO
{
    uint64_t speed;             // 速度 Byte/s
    uint64_t recv_bytes;        // 收到数据长度 Byte
} XL_RES_TRANSFER_INFO;

typedef struct TAG_XL_ADDITIONAL_RES_TRANSFER_INFO
{
    uint32_t res_type_count;            // 需要查询资源类型总数,不查询一定要初始化为0
    uint32_t *p_res_types;              // [调用者申请内存], 查询资源类型数组
    XL_RES_TRANSFER_INFO * p_infos;     // [调用者申请内存], 查询到资源的传输信息
} XL_ADDITIONAL_RES_RRANSFER_INFO;


typedef struct TAG_XL_TASK_INFO_EX
{
    uint32_t            len;                    // 结构体长度
    XL_TASK_STATUS      status;                 // 任务状态
    int32_t             errno_code;             // 错误码

    uint64_t  file_size;                        // 文件大小 Byte
    uint64_t  download_size;                    // 总的下载字节数
    uint64_t  download_speed;                   // 总的下载速度 Byte/s

    QUERY_INDEX_STATUS query_index_status;
    char cid[CID_SIZE];
    char gcid[CID_SIZE];

    XL_RES_TRANSFER_INFO origin;            // 原始资源下载信息
    XL_RES_TRANSFER_INFO p2s;               // 候选server资源传输信息
    XL_RES_TRANSFER_INFO p2p;               // 候选peer资源传输信息

    XL_ADDITIONAL_RES_RRANSFER_INFO additional_res;     // 加速资源传输信息

} XL_TASK_INFO;

typedef struct TAG_XL_TASK_INFO_EEX
{
    uint32_t            len;                     // 结构体长度
    int32_t             errno_code;              // 错误码（保留字段，值为0）

    uint32_t            p2s_used_total;          // 正在使用的p2s资源的数目
    uint32_t            p2p_used_total;          // 正在使用的p2p资源的数目
    uint32_t            p2s_abandon_total;       // 废弃的的p2s资源的数目
    uint32_t            p2p_abandon_total;       // 废弃的的p2p资源的数目
    ORIGIN_RES_STATE    origin_res_state;        // 原始资源状态

} XL_TASK_INFO_EX;


typedef struct TAG_XL_DOWNLOAD_LIB_INIT_PARAM
{
    const char *    pstrAppKey;             // 应用key
    uint32_t        nAppKeySize;

    const char *    pstrAppName;            // 应用名称
    uint32_t        nAppNameSize;

    const char *    pstrAppVersion;         // 应用版本号
    uint32_t        nAppVersionSize;

    const char*     pstrReservedField;      //保留字段
    uint32_t        nReservedFieldSize;

    const char *    pstrPeerId;
    uint32_t        nPeerIdSize;

    const char *    pstrGUID;               //手机机器码
    uint32_t        nGUIDSize;

    const char *    pstrStatSavePath;       // 哈勃统计数据持久化文件存储路径
    uint32_t        nStatSavePathSize;

    const char *    pstrStatCfgSavePath;    // 哈勃统计配置文件路径
    uint32_t        nStatCfgSavePathSize;

    NetWorkType     net;                    // 当前网络类型
    uint32_t		nDataBufferSize;
} InitParam, *PInitParam;

typedef struct TAG_TASK_PARAM
{
    XL_CREATE_TASK_MODE     mode;
    uint32_t                nSeqId;             // 上层统计序列id

    const char *            pstrUrl;            // 任务url
    uint32_t                nUrlSize;

    const char *            pstrRefUrl;          // 引用页
    uint32_t                nRefUrlSize;

    const char *            pstrCookie;         // Cookie
    uint32_t                nCookieSize;

    const char *            pstrUser;           // 登录用户名
    uint32_t                nUserSize;

    const char *            pstrPass;           // 登录密码
    uint32_t                nPassSize;

    const char *            pstrFilePath;       // 文件存储路径
    uint32_t                nFilePathSize;

    const char *            pstrFilename;       // 文件名
    uint32_t                nFilenameSize;

} TaskParam, *PTaskParam;

typedef struct TAG_TASK_PARAM_HLS
{
    XL_CREATE_TASK_MODE mode;
    uint32_t nSeqId;

    const char* pstrUrl;  //hls url
    uint32_t nUrlSize;

    const char* pstrFilePath;   //放置路径
    uint32_t nFilePathSize;

    const char* pstrFileName;   //文件名
    uint32_t nFileNameSize;
} TaskParamHls, *PTaskParamHls;

typedef struct TAG_DOWNLOAD_HEADER
{
    char   downloadHeader[MAX_HEADER_LEN];        // 报头缓冲区
    GET_DOWNLOAD_HEADER_STATE  state;             // 获取 http 报头运行状态
} DownloadHeader, *PDownloadHeader;

typedef struct TAG_SET_RELEASE_LOG_PARAM
{
    const char* logFilePath;  //full path with filename
    uint32_t    pathSize;
    uint32_t    logMaxSize;  //0=>default(10M) unit: MB
    uint32_t    logMaxCount;  //0=>default(10)
} SetRLogParam, *PSetRLogParam;

typedef struct TAG_TASK_PARAM_MAGNET
{
    const char* pstrUrl;  //magnet url
    uint32_t nUrlSize;

    const char* pstrFilePath;  //放置路径
    uint32_t nFilePathSize;

    const char* pstrFileName;  //文件名
    uint32_t nFileNameSize;
} TaskParamMagnet, *PTaskParamMagnet;

typedef struct TAG_TASK_PARAM_CID
{
    XL_CREATE_TASK_MODE mode;
    uint32_t nSeqId;

    const char* pCid;  //必填
    uint32_t nCidSize;  //只允许20字节长度

    const char* pGcid;  //选填
    uint32_t nGcidSize;

    const char* pBcid;  //选填
    uint32_t nBcidSize;

    uint64_t nFileSize;  //选填 虽然不填也可能查成功，但强烈要求填

    const char* pstrFilePath;   //放置路径
    uint32_t nFilePathSize;

    const char* pstrFileName;   //文件名
    uint32_t nFileNameSize;
} TaskParamCID, *PTaskParamCID;

typedef struct TAG_TASK_PARAM_EMULE
{
    XL_CREATE_TASK_MODE mode;
    uint32_t nSeqId;

    const char* pstrUrl;  //emule url
    uint32_t nUrlSize;

    const char* pstrFilePath;   //放置路径
    uint32_t nFilePathSize;

    const char* pstrFileName;   //文件名
    uint32_t nFileNameSize;
} TaskParamEmule, *PTaskParamEmule;

typedef struct TAG_TASK_PARAM_BT
{
    XL_CREATE_TASK_MODE mode;
    uint32_t nSeqId;
    uint32_t nMaxConcurrent; //最多同时下载运行子任务

    const char* pstrTorrentPath;  //local file path
    uint32_t nTorrentPathSize;

    const char* pstrFilePath;  //放置路径
    uint32_t nFilePathSize;
} TaskParamBt, *PTaskParamBt;

typedef struct TAG_BT_SUBTASK_DETAIL
{
    int32_t fileIndex;
    //char taskPath[MAX_FILEPATH_LEN]; // subA/filea.x
    uint32_t isSelect;  //0==FALSE 任务未被选,不下载不工作

    XL_TASK_INFO taskInfo;
} BtSubTaskDetail, *PBtSubTaskDetail;

//typedef enum ENUM_BT_SUB_TASK_STATUS
//{
//    BSTS_STOP,  //未工作,如果是选定的任务,后续可能开始工作
//    BSTS_RUNNING, //正在工作
//    BSTS_FINISH,  //完成
//    BSTS_ERROR   //失败,不会再开始。
//}BtSubTaskStatus;

typedef struct TAG_BT_TASK_STATUS
{
    XL_TASK_STATUS status;
} BtTaskStatus,*PBtTaskStatus;

//种子信息
typedef struct TAG_TORRENT_SUB_FILE_INFO
{
    int fileIndex;
    int realIndex;  //query XunLei server use.
    char fileName[MAX_FILENAME_LEN];
    char subPath[MAX_FILEPATH_LEN];  //如果有多层，使用 '/'连接
    uint64_t fileSize;
} TorrentFileInfo,*PTorrentFileInfo;

typedef struct TAG_TORRENT_INFO
{
    //input
    uint32_t countOfSubFileInfoStruct;  // 默认给0的话，subTaskInfo结构体不填充，根据subTaskCount分配结构体空间
    PTorrentFileInfo subFileInfo;  //数组起始，可用维数用countOfSubFileInfoStruct表示

    //output
    uint32_t fileCount;
    uint32_t isMultiFiles;  //是否多文件种子。 注：不能单纯以文件数量断定
    //只有多文件种子（isMultiFiles=true）有这个值，代表种子指定的bt任务的基础目录
    char multiFileBaseFolder[MAX_FILEPATH_LEN];
    char infoHash[INFO_HASH_SIZE];  //种子指纹

} TorrentInfo,*PTorrentInfo;

typedef struct TAG_THUNDER_URL_INFO
{
    char url[MAX_URL_LEN];
}ThunerUrlInfo, *PThunderUrlInfo;
typedef enum _QUICK_INFO_STATE
{
    QI_STOP=0,      //未开始，例如任务未开始
    QI_TRY=1,       //获取中，请换个时间再调
    QI_FINISH=2,    //获取完成
    QI_FAILED=3     //获取失败 可能存在部分数据
}QUICK_INFO_STATE;

typedef struct TAG_URL_QUICK_INFO
{
    QUICK_INFO_STATE state;
    char fileNameAdvice[MAX_FILENAME_LEN];
    char contentType[MAX_CONTENT_TYPE_LEN];
    int64_t fileSize;  // <0表示没取到
} UrlQuickInfo,*PUrlQuickInfo;


// 高速通道状态类型
typedef enum _HIGH_SPEED_CHANNEL_STATE
{
    HSCS_NONE = 0,      // 未进入高速通道
    HSCS_VIP = 1,       // 进入会员高速通道
    HSCS_TRY = 2        // 进入试用高速通道
}HIGH_SPEED_CHANNEL_STATE;

//************ interface from here *************
#ifdef __cplusplus
#define DOWNLOAD_LIB_API extern "C" XL_ERRNO_CODE
#else
#define DOWNLOAD_LIB_API  XL_ERRNO_CODE
#endif



// 初始化下载库
DOWNLOAD_LIB_API XLInit(/*in*/PInitParam pParam);


// 反初始化
DOWNLOAD_LIB_API XLUnInit();

// 通知当前网络类型
DOWNLOAD_LIB_API XLNotifyNetWorkType(/*in*/NetWorkType net);

// 通知wifi网络使用的BSSID
DOWNLOAD_LIB_API XLNotifyWifiBSSID(/*in*/const char* pstrBSSID, /*in*/uint32_t nBSSIDLen);

// 通知当前手机网络所使用的运营商
DOWNLOAD_LIB_API XLNotifyNetWorkCarrier(/*in*/NetWorkCarrier carrier);

// 设置用户id
DOWNLOAD_LIB_API XLSetUserId(/*in*/const char * pstrUserId, /*in*/uint32_t nUserIdLen);

// 设置机器mac地址
DOWNLOAD_LIB_API XLSetMac(/*in*/const char* pstrMac, /*in*/uint32_t nMacLen);

// 设置机器IMEI码
DOWNLOAD_LIB_API XLSetImei(/*in*/const char* pstrImei, /*in*/uint32_t nImeiLen);

DOWNLOAD_LIB_API XLSetLocalProperty(/*in*/const char* pstrKey, /*in*/uint32_t nKeyLen, /*in*/const char* pstrValue, /*in*/uint32_t nValueLen);

// 上层设置MiUi版本
// 版本信息最大长度为`MAX_SYSTEM_VERSION_LEN`
DOWNLOAD_LIB_API XLSetMiUiVersion(/*in*/const char * pMiUiVersion,  /*in*/uint32_t nLen);

// 获取下载库版本号
DOWNLOAD_LIB_API XLGetVersion(char version[MAX_VERSION_LEN]);

/*=============================================  以下是任务相关接口 ========================================*/
// 创建P2sp任务
DOWNLOAD_LIB_API XLCreateP2spTask(/*in*/PTaskParam pTaskParam, /*out*/uint64_t *pTaskId);
DOWNLOAD_LIB_API XLCreateHlsTask(/*in*/PTaskParamHls pTaskParam, /*out*/uint64_t *pTaskId);

// 销毁任务对象
DOWNLOAD_LIB_API XLReleaseTask(/*in*/uint64_t nTaskId);


// 设置创建任务的应用信息
DOWNLOAD_LIB_API XLSetTaskAppInfo(
    /*in*/uint64_t     nTaskId,
    /*in*/const char * pstrAppKey,
    /*in*/uint32_t     nAppKeySize,
    /*in*/const char * pstrAppName,
    /*in*/uint32_t     nAppNameSize,
    /*in*/const char * pstrAppVersion,
    /*in*/uint32_t     nAppversionSize
);

// 设置任务允许使用的资源类型
DOWNLOAD_LIB_API XLSetTaskAllowUseResource(/*in*/uint64_t nTaskId, /*in*/DOWNLOADLIB_RESOURCE_TYPE type);

// 设置任务创建者的UID
DOWNLOAD_LIB_API XLSetTaskUid(/*in*/uint64_t nTaskId, /*in*/uint32_t nUid);

// 开始任务
DOWNLOAD_LIB_API XLStartTask(/*in*/uint64_t nTaskId);

// 切换任务允许使用的资源类型
// 从只能使用原始资源到能使用全部资源
// 该接口仅限任务开始后停止前使用，且使用前任务是只允许使用原始资源的
DOWNLOAD_LIB_API XLSwitchOriginToAllResDownload(/*in*/uint64_t nTaskId);

// 停止任务 提供调用的原因代码
DOWNLOAD_LIB_API XLStopTask(/*in*/uint64_t nTaskId);
DOWNLOAD_LIB_API XLStopTaskWithReason(/*in*/uint64_t nTaskId, /*in*/ uint32_t nReasonCode);

// 获取任务信息
DOWNLOAD_LIB_API XLGetTaskInfo(/*in*/uint64_t nTaskId, /*out*/XL_TASK_INFO * pTaskInfo);
// 获取任务扩展信息
DOWNLOAD_LIB_API XLGetTaskInfoEx(/*in*/uint64_t nTaskId, /*out*/XL_TASK_INFO_EX * pTaskInfo);

/// 获取Task对应的Local Http Server的 local url
DOWNLOAD_LIB_API XLGetLocalUrl(const char* szFullFileName, int32_t nNameSize, char* szUrl, int32_t nUrlSize);
// 添加server资源
DOWNLOAD_LIB_API XLAddServerResource(
    /*in*/uint64_t nTaskId,
    /*in*/uint32_t nUrlLen,
    /*in*/const char *   pstrUrl,
    /*in*/uint32_t nRefUrlLen,
    /*in*/const char *   pstrRefUrl,
    /*in*/uint32_t nCookieLen,
    /*in*/const char *   pstrCookie,
    /*in*/uint32_t nAppDefinedType,
    /*in*/RES_USE_STRATEGY strategy
);

DOWNLOAD_LIB_API XLAddPeerResource(
    /*in*/uint64_t nTaskId,
    /*in*/const char *   pstrPeerID,
    /*in*/uint32_t nPeerIdLen,
    /*in*/uint64_t nUserId,
    /*in*/const char *   pstrJmpKey,
    /*in*/uint32_t nJmpKeyLen,
    /*in*/const char *   pstrVipCdnAuth,
    /*in*/uint32_t nVipCdnAuthLen,
    /*in*/uint32_t internalIp,
    /*in*/uint16_t tcpPort,
    /*in*/uint16_t udpPort,
    /*in*/uint8_t  resLevel,
    /*in*/uint8_t  resPriority,
    /*in*/uint32_t capabilityFlag,
    /*in*/uint32_t nAppDefinedType);
// 移除某类资源
DOWNLOAD_LIB_API XLRemoveAddedResource(/*in*/uint64_t nTaskId, /*in*/uint32_t nAppDefinedType);


// 重查索引
DOWNLOAD_LIB_API XLRequeryIndex(/*in*/uint64_t nTaskId);

// 上层传入http user agent
DOWNLOAD_LIB_API XLSetOriginUserAgent(/*in*/uint64_t nTaskId, /*in*/const char * pstrUserAgent, /*in*/uint32_t nUserAgentLen);

//上层获取http返回头
DOWNLOAD_LIB_API XLGetDownloadHeader(/*in*/uint64_t nTaskId, /*out*/PDownloadHeader pDownloadHeader);

//上层设置磁盘文件名称
DOWNLOAD_LIB_API XLSetFileName(/*in*/uint64_t nTaskId, /*in*/const char *pstrFileName, /*in*/uint32_t nFileNameLen);

//上层设置任务来源
DOWNLOAD_LIB_API XLSetDownloadTaskOrigin(/*in*/uint64_t nTaskId, /*in*/const char* pTaskOrigin, /*in*/uint32_t nTaskOriginLen);

// 上层传入Http header
DOWNLOAD_LIB_API XLSetHttpHeaderProperty(/*in*/uint64_t nTaskId, /*in*/const char *pstrName,  /*in*/uint32_t nNameLen, /*in*/const char *pstrValue, /*in*/uint32_t nValueLen);

//仅用于release输日志版本开启日志输出。 turnOn=0是off  =1时打开。 off的时候pParam可以为NULL
DOWNLOAD_LIB_API XLSetReleaseLog(uint32_t turnOn, PSetRLogParam pParam);
DOWNLOAD_LIB_API XLIsLogTurnOn(uint32_t *isTurnOn);  //==0 false;  !=0 true

//上层设置xl_stat上报开关 reportSwitch=false  表示只在有任务的时候才上报， reportSwitch=true  没有任务的时候也可以上报.
//不调用该接口，默认情况，没有任务的时候也可以上报
DOWNLOAD_LIB_API XLSetStatReportSwitch(bool reportSwitch);
//=======================
// 手雷集成追加的功能接口函数
//=======================

//设置高速/离线状态，目前非0都会当作进入通道处理，用于统计分析(磁链任务没有效果)
DOWNLOAD_LIB_API XLSetTaskLxState(/*in*/uint64_t nTaskId, int32_t nSubIndex, uint32_t nLxState);
DOWNLOAD_LIB_API XLSetTaskGsState(/*in*/uint64_t nTaskId, int32_t nSubIndex, HIGH_SPEED_CHANNEL_STATE nGsState);

//进入预取模式获取信息尽量不下载数据。必须在StartTask前调用。(bt、磁链任务没有效果)
DOWNLOAD_LIB_API XLEnterPrefetchMode(/*in*/uint64_t nTaskId);

//上层获取http返回头  当idx=0时state为GDHS_SUCCESS
//可以依次++idx获取可能存在跳转的其他http头 拿到的顺序和获取的时序正好相反
DOWNLOAD_LIB_API XLGetDownloadHeaders(/*in*/uint64_t nTaskId, uint32_t idx,/*out*/PDownloadHeader pDownloadHeader);

//只清理临时文件，不清理任务文件本身。
//只要存在续传可能，都不应该移除cfg。特别是bt任务下完部分文件后，仍可能续传其他子任务
//XLStopTask后调用
DOWNLOAD_LIB_API XLRemoveTaskCfg(/*in*/uint64_t nTaskId);

// 创建磁链任务，只能处理bt类型磁链， 只获取对应的种子文件。
// 使用方式和常规任务一样
DOWNLOAD_LIB_API XLCreateBtMagnetTask( /*in*/PTaskParamMagnet pTaskParam, /*out*/uint64_t *pTaskId);
DOWNLOAD_LIB_API XLCreateCIDTask( /*in*/PTaskParamCID pTaskParam, /*out*/uint64_t *pTaskId);
DOWNLOAD_LIB_API XLCreateEmuleTask( /*in*/PTaskParamEmule pTaskParam, /*out*/uint64_t *pTaskId);
DOWNLOAD_LIB_API XLCreateBtTask( /*in*/PTaskParamBt pTaskParam, /*out*/uint64_t *pTaskId);

// 获取torrent信息。提供一定空间给下载库填。pTorrentInfo是数组[0]的地址
// 如果不够，返相相应的errcode，subTaskCount为最少需要的数组维度，重新调用一次
DOWNLOAD_LIB_API XLGetTorrentInfo(const char* localFullPath, uint32_t pathSize, PTorrentInfo pTorrentInfo);

// 获取正在工作的子任务 最多获取count个。 可以固定使用nMaxConcurrent作为count
//XL_ERRNO_CODE XLGetBtTaskInfo(uint64_t nTaskId, PBtSubTaskDetail subTaskDetail, uint32_t count);
// 获取所有任务的状态， 上层根据状态自行决定是否XLGetBtSubTaskInfo获取子任务信息。
DOWNLOAD_LIB_API XLGetBtSubTaskStatus(uint64_t nTaskId, PBtTaskStatus subTaskStatus, uint32_t start, uint32_t count);

// 获取单个子任务详细信息
DOWNLOAD_LIB_API XLGetBtSubTaskInfo(uint64_t nTaskId, int32_t nFileIndex, PBtSubTaskDetail subTaskDetail);

// indexSet数组每个值代表一个fileIndex， 这些fileIndex的任务将会被切换
DOWNLOAD_LIB_API XLBtSelectSubTask(uint64_t nTaskId, uint32_t* indexSet, uint32_t count);
DOWNLOAD_LIB_API XLBtDeselectSubTask(uint64_t nTaskId, uint32_t* indexSet, uint32_t count);
DOWNLOAD_LIB_API XLBtAddServerResource(uint64_t nTaskId,
                                       int32_t  nSubIndex,
                                       uint32_t nUrlLen,
                                       const char *   pstrUrl,
                                       uint32_t nRefUrlLen,
                                       const char *   pstrRefUrl,
                                       uint32_t nCookieLen,
                                       const char *   pstrCookie,
                                       uint32_t nAppDefinedType,
                                       RES_USE_STRATEGY strategy);
DOWNLOAD_LIB_API XLBtAddPeerResource(uint64_t nTaskId,
                                     int32_t  nSubIndex,
                                     const char *   pstrPeerID,
                                     uint32_t nPeerIdLen,
                                     uint64_t nUserId,
                                     const char *   pstrJmpKey,
                                     uint32_t nJmpKeyLen,
                                     const char *   pstrVipCdnAuth,
                                     uint32_t nVipCdnAuthLen,
                                     uint32_t internalIp,
                                     uint16_t tcpPort,
                                     uint16_t udpPort,
                                     uint8_t  resLevel,
                                     uint8_t  resPriority,
                                     uint32_t capabilityFlag,
                                     uint32_t nAppDefinedType);
// 移除某类资源
DOWNLOAD_LIB_API XLBtRemoveAddedResource(/*in*/uint64_t nTaskId, /*in*/int32_t nSubIndex, /*in*/uint32_t nAppDefinedType);

//解析迅雷专用链
DOWNLOAD_LIB_API XLParserThunderUrl(const char* url, uint32_t nUrlLen, PThunderUrlInfo pUrlThunderInfo);

DOWNLOAD_LIB_API XLGetUrlQuickInfo(/*in*/uint64_t nTaskId,PUrlQuickInfo pUrlQuickInfo);

DOWNLOAD_LIB_API XLGetFileNameFromUrl(const char* pUrl, uint32_t nUrlSize, char* pFileName, uint32_t nFileNameLen);

DOWNLOAD_LIB_API XLGetFileNameFromHlsUrl(const char* pUrl, uint32_t nUrlSize, char* pFileName, uint32_t nFileNameLen);

#endif
